Changing uses of --driver= to --device= (that I can find).
diff --git a/build_tools/bazel/iree_check_test.bzl b/build_tools/bazel/iree_check_test.bzl
index 0d23dbd..e60d5d9 100644
--- a/build_tools/bazel/iree_check_test.bzl
+++ b/build_tools/bazel/iree_check_test.bzl
@@ -67,7 +67,7 @@
     native_test(
         name = name,
         args = [
-            "--driver=%s" % driver,
+            "--device=%s" % driver,
             "$(location :%s)" % bytecode_module_name,
         ] + runner_args,
         data = [":%s" % bytecode_module_name],
diff --git a/build_tools/bazel/iree_trace_runner_test.bzl b/build_tools/bazel/iree_trace_runner_test.bzl
index ff6ee3a..446857d 100644
--- a/build_tools/bazel/iree_trace_runner_test.bzl
+++ b/build_tools/bazel/iree_trace_runner_test.bzl
@@ -65,7 +65,7 @@
     native_test(
         name = name,
         args = [
-            "--driver=%s" % driver,
+            "--device=%s" % driver,
             "$(location :%s)" % trace,
         ] + runner_args,
         data = [
diff --git a/build_tools/benchmarks/comparisons/common/benchmark_command.py b/build_tools/benchmarks/comparisons/common/benchmark_command.py
index abb1dd5..a00469e 100644
--- a/build_tools/benchmarks/comparisons/common/benchmark_command.py
+++ b/build_tools/benchmarks/comparisons/common/benchmark_command.py
@@ -129,7 +129,7 @@
 
   def generate_benchmark_command(self) -> list[str]:
     command = super().generate_benchmark_command()
-    command.append("--driver=" + self.driver)
+    command.append("--device=" + self.driver)
     command.append("--task_topology_group_count=" + str(self.num_threads))
     command.append("--benchmark_repetitions=" + str(self.num_runs))
     return command
diff --git a/build_tools/cmake/iree_benchmark_suite.cmake b/build_tools/cmake/iree_benchmark_suite.cmake
index ca7202c..8c93b08 100644
--- a/build_tools/cmake/iree_benchmark_suite.cmake
+++ b/build_tools/cmake/iree_benchmark_suite.cmake
@@ -300,7 +300,7 @@
         COMMAND
           "${Python3_EXECUTABLE}" "${IREE_ROOT_DIR}/build_tools/scripts/generate_flagfile.py"
             --module_file="${_MODULE_FILE_FLAG}"
-            --driver=${_RULE_DRIVER}
+            --device=${_RULE_DRIVER}
             --entry_function=${_MODULE_ENTRY_FUNCTION}
             --function_inputs=${_MODULE_FUNCTION_INPUTS}
             "${_ADDITIONAL_ARGS_CL}"
diff --git a/build_tools/kokoro/gcp_ubuntu/cmake/linux/riscv64/tests/lit.cfg.py b/build_tools/kokoro/gcp_ubuntu/cmake/linux/riscv64/tests/lit.cfg.py
index 562ca6a..08e8dc0 100644
--- a/build_tools/kokoro/gcp_ubuntu/cmake/linux/riscv64/tests/lit.cfg.py
+++ b/build_tools/kokoro/gcp_ubuntu/cmake/linux/riscv64/tests/lit.cfg.py
@@ -20,7 +20,7 @@
     (os.getenv("QEMU_RV64_BIN"), os.getenv("RISCV_TOOLCHAIN_ROOT")))
 
 config.environment["TEST_MODULE_CMD"] = (
-    "%s %s/tools/iree-run-module --driver=local-task" %
+    "%s %s/tools/iree-run-module --device=local-task" %
     (config.environment["TEST_CMD"], os.getenv("BUILD_RISCV_DIR")))
 
 config.test_exec_root = os.getenv("BUILD_RISCV_DIR") + \
diff --git a/build_tools/scripts/generate_flagfile.py b/build_tools/scripts/generate_flagfile.py
index 87c5ef1..5a7fe26 100755
--- a/build_tools/scripts/generate_flagfile.py
+++ b/build_tools/scripts/generate_flagfile.py
@@ -19,11 +19,11 @@
                       required=True,
                       metavar="<module-file>",
                       help="The name of the module file")
-  parser.add_argument("--driver",
+  parser.add_argument("--device",
                       type=str,
                       required=True,
-                      metavar="<driver>",
-                      help="The name of the IREE driver")
+                      metavar="<device>",
+                      help="The name of the HAL device")
   parser.add_argument("--entry_function",
                       type=str,
                       required=True,
@@ -50,7 +50,7 @@
 
 def main(args):
   lines = [
-      f"--driver={args.driver}", f"--module_file={args.module_file}",
+      f"--device={args.device}", f"--module_file={args.module_file}",
       f"--entry_function={args.entry_function}"
   ]
   lines.extend([
diff --git a/docs/developers/design_docs/cuda_backend.md b/docs/developers/design_docs/cuda_backend.md
index 3e943ab..f85399e 100644
--- a/docs/developers/design_docs/cuda_backend.md
+++ b/docs/developers/design_docs/cuda_backend.md
@@ -85,7 +85,7 @@
 
 # Run the module through CUDA HAL backend.
 $ ../iree-build/tools/iree-run-module \
-  --driver=cuda \
+  --device=cuda \
   --module_file=/tmp/mhlo-add.vmfb \
   --entry_function=add \
   --function_input="4xf32=[1 2 3 4]" \
diff --git a/docs/developers/developing_iree/benchmarking.md b/docs/developers/developing_iree/benchmarking.md
index bdc590f..7e32fda 100644
--- a/docs/developers/developing_iree/benchmarking.md
+++ b/docs/developers/developing_iree/benchmarking.md
@@ -31,7 +31,7 @@
 ```shell
 $ bazel run //tools:iree-benchmark-module -- \
   --module_file=/tmp/module.fb \
-  --driver=local-task \
+  --device=local-task \
   --entry_function=abs \
   --function_input=f32=-2
 ```
@@ -78,7 +78,7 @@
 ```shell
 $ ./bazel-bin/tools/iree-benchmark-module \
   --module_file=/tmp/module.fb \
-  --driver=local-task \
+  --device=local-task \
   --entry_function=abs \
   --function_input=f32=-2
 ```
@@ -122,7 +122,7 @@
 ```shell
 $ build/tools/iree-benchmark-module
   --module_file=/tmp/fullyconnected.vmfb
-  --driver=local-task
+  --device=local-task
 ```
 
 If no `entry_function` is specified, `iree-benchmark-module` will register a
diff --git a/docs/developers/developing_iree/developer_overview.md b/docs/developers/developing_iree/developer_overview.md
index 3eef331..77516ba 100644
--- a/docs/developers/developing_iree/developer_overview.md
+++ b/docs/developers/developing_iree/developer_overview.md
@@ -140,7 +140,7 @@
 ```shell
 $ ../iree-build/tools/iree-run-module \
   --module_file=/tmp/simple_abs_vmvx.vmfb \
-  --driver=local-task \
+  --device=local-task \
   --entry_function=abs \
   --function_input=f32=-2
 ```
@@ -165,7 +165,7 @@
 ```shell
 $ ../iree-build/tools/iree-check-module \
   /tmp/abs.vmfb \
-  --driver=local-task
+  --device=local-task
 ```
 
 ### iree-run-mlir
diff --git a/docs/developers/developing_iree/e2e_benchmarking.md b/docs/developers/developing_iree/e2e_benchmarking.md
index 201c295..84c9fae 100644
--- a/docs/developers/developing_iree/e2e_benchmarking.md
+++ b/docs/developers/developing_iree/e2e_benchmarking.md
@@ -117,7 +117,7 @@
 ```shell
 $ tools/iree-benchmark-module \
   --module_file=/tmp/iree/modules/MatrixOpsStaticModule/iree_vmvx/compiled.vmfb \
-  --driver=local-task \
+  --device=local-task \
   --entry_function=matmul_lhs_batch \
   --function_input=256x64x32xf32=2 \
   --function_input=32x16xf32=3
@@ -221,7 +221,7 @@
 ```shell
 $ adb shell /data/local/tmp/iree-benchmark-module \
   --module_file="/data/local/tmp/MatrixOpsStaticModule/iree_vmvx/compiled.vmfb" \
-  --driver=local-task \
+  --device=local-task \
   --entry_function=matmul_lhs_batch \
   --function_input=256x64x32xf32=2 \
   --function_input=32x16xf32=3
diff --git a/docs/developers/developing_iree/profiling_cpu_events.md b/docs/developers/developing_iree/profiling_cpu_events.md
index 84ca334..0f2110b 100644
--- a/docs/developers/developing_iree/profiling_cpu_events.md
+++ b/docs/developers/developing_iree/profiling_cpu_events.md
@@ -63,7 +63,7 @@
 ```shell
 perf record -o /tmp/perf.data \
   ./tools/iree-benchmark-module \
-    --driver=local-task \
+    --device=local-task \
     ... command-line arguments of iree-benchmark-module as usual ...
 ```
 
@@ -73,7 +73,7 @@
 ```shell
 perf record -o /tmp/perf.data -e L1-dcache-load-misses \
   ./tools/iree-benchmark-module \
-    --driver=local-task \
+    --device=local-task \
     ... command-line arguments of iree-benchmark-module as usual ...
 ```
 
@@ -150,7 +150,7 @@
 adb shell \
   simpleperf record -e raw-l1d-cache-refill -o /data/local/tmp/perf.data \
     /data/local/tmp/iree-benchmark-module \
-      --driver=local-task \
+      --device=local-task \
       ... command-line arguments of iree-benchmark-module as usual ...
 ```
 
diff --git a/docs/developers/developing_iree/profiling_vulkan_gpu.md b/docs/developers/developing_iree/profiling_vulkan_gpu.md
index 2650738..7fdd21a 100644
--- a/docs/developers/developing_iree/profiling_vulkan_gpu.md
+++ b/docs/developers/developing_iree/profiling_vulkan_gpu.md
@@ -45,7 +45,7 @@
 # Then package the Android app
 $ /path/to/iree/source/tools/android/run_module_app/build_apk.sh \
   ./build-apk \
-  --driver vulkan \
+  --device vulkan \
   --module_file /tmp/mhlo-dot.vmfb \
   --entry_function dot \
   --function_input=...
diff --git a/docs/developers/developing_iree/profiling_with_tracy.md b/docs/developers/developing_iree/profiling_with_tracy.md
index b516fd3..adfa6fa 100644
--- a/docs/developers/developing_iree/profiling_with_tracy.md
+++ b/docs/developers/developing_iree/profiling_with_tracy.md
@@ -126,7 +126,7 @@
 
 ```shell
 TRACY_NO_EXIT=1 /data/local/tmp/iree-benchmark-module \
-  --driver=local-task \
+  --device=local-task \
   --module_file=/data/local/tmp/android_module.fbvm \
   --entry_function=serving_default \
   --function_input=1x384xi32 \
diff --git a/docs/website/docs/building-from-source/android.md b/docs/website/docs/building-from-source/android.md
index cf09530..6642fa2 100644
--- a/docs/website/docs/building-from-source/android.md
+++ b/docs/website/docs/building-from-source/android.md
@@ -127,7 +127,7 @@
 Run the tool:
 
 ``` shell
-adb shell /data/local/tmp/iree-run-module --driver=local-task \
+adb shell /data/local/tmp/iree-run-module --device=local-task \
   --module_file=/data/local/tmp/simple_abs_vmvx.vmfb \
   --entry_function=abs \
   --function_input="f32=-5"
diff --git a/docs/website/docs/building-from-source/riscv.md b/docs/website/docs/building-from-source/riscv.md
index db4b282..78b73ee 100644
--- a/docs/website/docs/building-from-source/riscv.md
+++ b/docs/website/docs/building-from-source/riscv.md
@@ -117,7 +117,7 @@
   -cpu rv64 \
   -L ${RISCV_TOOLCHAIN_ROOT}/sysroot/ \
   ../iree-build-riscv/tools/iree-run-module \
-  --driver=local-task \
+  --device=local-task \
   --module_file=/tmp/simple_abs_vmvx.vmfb \
   --entry_function=abs \
   --function_input=f32=-5
@@ -163,7 +163,7 @@
   -cpu rv64,x-v=true,x-k=true,vlen=256,elen=64,vext_spec=v1.0 \
   -L ${RISCV_TOOLCHAIN_ROOT}/sysroot/ \
   ../iree-build-riscv/tools/iree-run-module \
-  --driver=local-task \
+  --device=local-task \
   --module_file=mobilenet_cpu.vmfb \
   --entry_function=predict \
   --function_input="1x224x224x3xf32=0"
diff --git a/docs/website/docs/deployment-configurations/cpu.md b/docs/website/docs/deployment-configurations/cpu.md
index 533c558..a7fb28f 100644
--- a/docs/website/docs/deployment-configurations/cpu.md
+++ b/docs/website/docs/deployment-configurations/cpu.md
@@ -126,7 +126,7 @@
 
 ``` shell hl_lines="2"
 tools/iree-run-module \
-    --driver=local-task \
+    --device=local-task \
     --module_file=mobilenet_cpu.vmfb \
     --entry_function=predict \
     --function_input="1x224x224x3xf32=0"
diff --git a/docs/website/docs/deployment-configurations/gpu-cuda-rocm.md b/docs/website/docs/deployment-configurations/gpu-cuda-rocm.md
index ac56d45..4575968 100644
--- a/docs/website/docs/deployment-configurations/gpu-cuda-rocm.md
+++ b/docs/website/docs/deployment-configurations/gpu-cuda-rocm.md
@@ -158,7 +158,7 @@
 
     ``` shell hl_lines="2"
     tools/iree-run-module \
-        --driver=cuda \
+        --device=cuda \
         --module_file=mobilenet-cuda.vmfb \
         --entry_function=predict \
         --function_input="1x224x224x3xf32=0"
@@ -168,7 +168,7 @@
 
     ``` shell hl_lines="2"
     tools/iree-run-module \
-        --driver=rocm \
+        --device=rocm \
         --module_file=mobilenet-rocm.vmfb \
         --entry_function=predict \
         --function_input="1x224x224x3xf32=0"
diff --git a/docs/website/docs/deployment-configurations/gpu-vulkan.md b/docs/website/docs/deployment-configurations/gpu-vulkan.md
index 05aecc7..03b58eb 100644
--- a/docs/website/docs/deployment-configurations/gpu-vulkan.md
+++ b/docs/website/docs/deployment-configurations/gpu-vulkan.md
@@ -176,7 +176,7 @@
 
 ``` shell hl_lines="2"
 tools/iree-run-module \
-    --driver=vulkan \
+    --device=vulkan \
     --module_file=mobilenet-vulkan.vmfb \
     --entry_function=predict \
     --function_input="1x224x224x3xf32=0"
diff --git a/experimental/web/run_native_benchmarks.sh b/experimental/web/run_native_benchmarks.sh
index db212c2..2f4daee 100644
--- a/experimental/web/run_native_benchmarks.sh
+++ b/experimental/web/run_native_benchmarks.sh
@@ -34,7 +34,7 @@
 echo "Benchmarking DeepLabV3..."
 "${IREE_BENCHMARK_MODULE_PATH?}" \
     --module_file=./deeplabv3_native.vmfb \
-    --driver=local-task \
+    --device=local-task \
     --task_topology_group_count=1 \
     --entry_function=main \
     --function_input=1x257x257x3xf32 \
@@ -44,7 +44,7 @@
 echo "Benchmarking MobileSSD..."
 "${IREE_BENCHMARK_MODULE_PATH?}" \
     --module_file=./mobile_ssd_v2_float_coco_native.vmfb \
-    --driver=local-task \
+    --device=local-task \
     --task_topology_group_count=1 \
     --entry_function=main \
     --function_input=1x320x320x3xf32 \
@@ -54,7 +54,7 @@
 echo "Benchmarking PoseNet..."
 "${IREE_BENCHMARK_MODULE_PATH?}" \
     --module_file=./posenet_native.vmfb \
-    --driver=local-task \
+    --device=local-task \
     --task_topology_group_count=1 \
     --entry_function=main \
     --function_input=1x353x257x3xf32 \
@@ -64,7 +64,7 @@
 echo "Benchmarking MobileBertSquad..."
 "${IREE_BENCHMARK_MODULE_PATH?}" \
     --module_file=./mobilebertsquad_native.vmfb \
-    --driver=local-task \
+    --device=local-task \
     --task_topology_group_count=1 \
     --entry_function=main \
     --function_input=1x384xi32 \
@@ -76,7 +76,7 @@
 echo "Benchmarking MobileNetV2..."
 "${IREE_BENCHMARK_MODULE_PATH?}" \
     --module_file=./mobilenet_v2_1.0_224_native.vmfb \
-    --driver=local-task \
+    --device=local-task \
     --task_topology_group_count=1 \
     --entry_function=main \
     --function_input=1x224x224x3xf32 \
@@ -86,7 +86,7 @@
 echo "Benchmarking MobileNetV3Small..."
 "${IREE_BENCHMARK_MODULE_PATH?}" \
     --module_file=./MobileNetV3SmallStaticBatch_native.vmfb \
-    --driver=local-task \
+    --device=local-task \
     --task_topology_group_count=1 \
     --entry_function=main \
     --function_input=1x224x224x3xf32 \
diff --git a/experimental/web/testing/parse_test_list.py b/experimental/web/testing/parse_test_list.py
index 63f17a1..8ca2d06 100644
--- a/experimental/web/testing/parse_test_list.py
+++ b/experimental/web/testing/parse_test_list.py
@@ -73,7 +73,7 @@
 
       # Parse the 'command' list into the source file and its arguments.
       #   /path/to/test_runner.js  # such as iree-check-module.js or test.js
-      #   arg 1                    # such as --driver=local-task
+      #   arg 1                    # such as --device=local-task
       #   arg 2                    # such as check_vmvx_op.mlir_module.vmfb
       test_source_absolute_path = test["command"][0]
       parsed_test["sourceFile"] = get_normalized_relative_path(
diff --git a/integrations/tensorflow/python_projects/iree_tf/iree/tf/support/trace_utils.py b/integrations/tensorflow/python_projects/iree_tf/iree/tf/support/trace_utils.py
index 8a38d34..5f269cf 100644
--- a/integrations/tensorflow/python_projects/iree_tf/iree/tf/support/trace_utils.py
+++ b/integrations/tensorflow/python_projects/iree_tf/iree/tf/support/trace_utils.py
@@ -285,7 +285,7 @@
         serialized_inputs = self.calls[0].serialized_inputs
         flagfile = [
             f"--module_file={compiled_path}",
-            f"--driver={self.backend_driver}",
+            f"--device={self.backend_driver}",
             f"--entry_function={entry_function}",
         ] + [f"--function_input={input}" for input in serialized_inputs]
         with open(os.path.join(trace_dir, "flagfile"), "w") as f:
diff --git a/runtime/src/iree/modules/check/test/failure.mlir b/runtime/src/iree/modules/check/test/failure.mlir
index 53a567e..ecf8294 100644
--- a/runtime/src/iree/modules/check/test/failure.mlir
+++ b/runtime/src/iree/modules/check/test/failure.mlir
@@ -1,5 +1,5 @@
 // RUN: iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-check-module --expect_failure - | FileCheck %s
-// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-check-module --driver=vulkan --expect_failure - | FileCheck %s)
+// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-check-module --device=vulkan --expect_failure - | FileCheck %s)
 
 // CHECK-LABEL: expect_failure.expect_true_of_false
 // CHECK: Expected 0 to be nonzero
diff --git a/runtime/src/iree/modules/check/test/success.mlir b/runtime/src/iree/modules/check/test/success.mlir
index 6dc937a..845397e 100644
--- a/runtime/src/iree/modules/check/test/success.mlir
+++ b/runtime/src/iree/modules/check/test/success.mlir
@@ -1,5 +1,5 @@
-// RUN: iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-check-module --driver=local-task -
-// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-check-module --driver=vulkan -)
+// RUN: iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-check-module --device=local-task -
+// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-check-module --device=vulkan -)
 
 func.func @expect_true() {
   %true = util.unfoldable_constant 1 : i32
diff --git a/tools/android/run_module_app/README.md b/tools/android/run_module_app/README.md
index 6bca552..9f7ae4d 100644
--- a/tools/android/run_module_app/README.md
+++ b/tools/android/run_module_app/README.md
@@ -44,7 +44,7 @@
       Android API level.
    1. Copy the VM FlatBuffer as `assets/module.vmfb`, write the entry function
       input buffers, and HAL driver into `assets/entry_function.txt`,
-      `assets/inputs.txt`, and `assets/driver.txt`, respectively.
+      `assets/inputs.txt`, and `assets/device.txt`, respectively.
    1. Copy the shared library under `lib/<android-abi>/`.
    1. Compile resources under [`res/`](./res) directory into an Android DEX
       file.
diff --git a/tools/android/run_module_app/build_apk.sh b/tools/android/run_module_app/build_apk.sh
index 588a799..3bad7c1 100644
--- a/tools/android/run_module_app/build_apk.sh
+++ b/tools/android/run_module_app/build_apk.sh
@@ -25,7 +25,7 @@
 
 print_usage_and_exit() {
   echo "Usage: $0 <artifact-directory> "
-  echo "       --driver <driver>"
+  echo "       --device <device>"
   echo "       --module_file <input-module-file> "
   echo "       --entry_function <entry-function> "
   echo "       --function_inputs_file <input-buffer-file> "
@@ -34,9 +34,9 @@
 
 while (( "$#" )); do
   case "$1" in
-    --driver)
+    --device)
       if [[ -n "$2" ]] && [[ ${2:0:1} != "-" ]]; then
-        IREE_DRIVER=$2
+        IREE_DEVICE=$2
         shift 2
       else
         echo "Error: missing argument for $1" >&2
@@ -88,7 +88,7 @@
 
 if [[ -z "${IREE_ARTIFACT_ROOT}" ]] || [[ -z "${IREE_INPUT_MODULE_FILE}" ]] || \
    [[ -z "${IREE_ENTRY_FUNCTION}" ]] || [[ -z "${IREE_INPUT_BUFFER_FILE}" ]] || \
-   [[ -z "${IREE_DRIVER}" ]]; then
+   [[ -z "${IREE_DEVICE}" ]]; then
   echo "Error: missing necessary parameters" >&2
   print_usage_and_exit
 fi
@@ -231,7 +231,7 @@
 cp "${IREE_INPUT_MODULE_FILE?}" "${IREE_ASSET_DIR?}/module.vmfb"
 cp "${IREE_INPUT_BUFFER_FILE?}" "${IREE_ASSET_DIR?}/inputs.txt"
 echo -n "${IREE_ENTRY_FUNCTION?}" > "${IREE_ASSET_DIR?}/entry_function.txt"
-echo -n "${IREE_DRIVER?}" > "${IREE_ASSET_DIR?}/driver.txt"
+echo -n "${IREE_DEVICE?}" > "${IREE_ASSET_DIR?}/device.txt"
 
 echo ">>> Compiling app resources <<<"
 
diff --git a/tools/android/run_module_app/src/main.cc b/tools/android/run_module_app/src/main.cc
index 83dc07f..16a6198 100644
--- a/tools/android/run_module_app/src/main.cc
+++ b/tools/android/run_module_app/src/main.cc
@@ -31,14 +31,14 @@
 const char kModuleFileName[] = "module.vmfb";
 const char kEntryFunctionFileName[] = "entry_function.txt";
 const char kInputsFileName[] = "inputs.txt";
-const char kDriverFileName[] = "driver.txt";
+const char kDeviceFileName[] = "device.txt";
 
 // A struct containing information regarding one IREE VM module invocation.
 struct IreeModuleInvocation {
   std::string module;
   std::string entry_function;
   std::string inputs;
-  std::string driver;
+  std::string device;
 };
 
 // A class for loading IREE module invocation information from Android apk asset
@@ -54,7 +54,7 @@
     IREE_RETURN_IF_ERROR(
         ReadFileAsset(kEntryFunctionFileName, &invocation.entry_function));
     IREE_RETURN_IF_ERROR(ReadFileAsset(kInputsFileName, &invocation.inputs));
-    IREE_RETURN_IF_ERROR(ReadFileAsset(kDriverFileName, &invocation.driver));
+    IREE_RETURN_IF_ERROR(ReadFileAsset(kDeviceFileName, &invocation.device));
     *out_invocation = std::move(invocation);
     return OkStatus();
   }
@@ -104,7 +104,7 @@
   iree_hal_device_t* device = nullptr;
   IREE_RETURN_IF_ERROR(iree_hal_create_device(
       iree_hal_available_driver_registry(),
-      iree_make_string_view(invocation.driver.data(), invocation.driver.size()),
+      iree_make_string_view(invocation.device.data(), invocation.device.size()),
       iree_allocator_system(), &device));
   iree_vm_module_t* hal_module = nullptr;
   IREE_RETURN_IF_ERROR(
@@ -178,7 +178,7 @@
   if (status.ok()) {
     LOGI("entry function: '%s'", invocation.entry_function.c_str());
     LOGI("inputs:\n%s", invocation.inputs.c_str());
-    LOGI("driver: '%s'", invocation.driver.c_str());
+    LOGI("device: '%s'", invocation.device.c_str());
     status = RunModule(invocation);
     if (!status.ok()) LOGE("%s", status.ToString().c_str());
   } else {
diff --git a/tools/test/benchmark_flags.txt b/tools/test/benchmark_flags.txt
index 32b2343..b8a251b 100644
--- a/tools/test/benchmark_flags.txt
+++ b/tools/test/benchmark_flags.txt
@@ -2,7 +2,7 @@
 // HELP: --module_file
 // HELP: --benchmark_list_tests
 
-// RUN: ( iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --benchmark_list_tests --driver=local-task --benchmark_list_tests ) | FileCheck --check-prefix=LIST-BENCHMARKS %s
+// RUN: ( iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --benchmark_list_tests --device=local-task --benchmark_list_tests ) | FileCheck --check-prefix=LIST-BENCHMARKS %s
 module {
   // LIST-BENCHMARKS: BM_foo1
   func.func @foo1() -> tensor<4xf32> {
diff --git a/tools/test/iree-benchmark-module.mlir b/tools/test/iree-benchmark-module.mlir
index 6bdd25f..84a2bef 100644
--- a/tools/test/iree-benchmark-module.mlir
+++ b/tools/test/iree-benchmark-module.mlir
@@ -1,6 +1,6 @@
-// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=local-task --entry_function=abs --function_input=f32=-2 | FileCheck %s
-// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=vulkan --entry_function=abs --function_input=f32=-2 | FileCheck %s)
-// RUN: iree-compile --iree-hal-target-backends=dylib-llvm-aot --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=local-task --entry_function=abs --function_input=f32=-2 | FileCheck %s
+// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=local-task --entry_function=abs --function_input=f32=-2 | FileCheck %s
+// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=vulkan --entry_function=abs --function_input=f32=-2 | FileCheck %s)
+// RUN: iree-compile --iree-hal-target-backends=dylib-llvm-aot --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=local-task --entry_function=abs --function_input=f32=-2 | FileCheck %s
 
 // CHECK-LABEL: BM_abs
 func.func @abs(%input : tensor<f32>) -> (tensor<f32>) {
diff --git a/tools/test/iree-run-module.mlir b/tools/test/iree-run-module.mlir
index 4df9434..ca69b22 100644
--- a/tools/test/iree-run-module.mlir
+++ b/tools/test/iree-run-module.mlir
@@ -1,6 +1,6 @@
-// RUN: (iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-run-module --driver=local-task --entry_function=abs --function_input=f32=-2) | FileCheck %s
-// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || ((iree-compile --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-run-module --driver=vulkan --entry_function=abs --function_input=f32=-2) | FileCheck %s)
-// RUN: (iree-compile --iree-hal-target-backends=dylib-llvm-aot --iree-mlir-to-vm-bytecode-module %s | iree-run-module --driver=local-task --entry_function=abs --function_input=f32=-2) | FileCheck %s
+// RUN: (iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-run-module --device=local-task --entry_function=abs --function_input=f32=-2) | FileCheck %s
+// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || ((iree-compile --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-run-module --device=vulkan --entry_function=abs --function_input=f32=-2) | FileCheck %s)
+// RUN: (iree-compile --iree-hal-target-backends=dylib-llvm-aot --iree-mlir-to-vm-bytecode-module %s | iree-run-module --device=local-task --entry_function=abs --function_input=f32=-2) | FileCheck %s
 
 // CHECK-LABEL: EXEC @abs
 func.func @abs(%input : tensor<f32>) -> (tensor<f32>) {
diff --git a/tools/test/multiple_args.mlir b/tools/test/multiple_args.mlir
index fa4760e..01df804 100644
--- a/tools/test/multiple_args.mlir
+++ b/tools/test/multiple_args.mlir
@@ -1,6 +1,6 @@
 // RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-run-module --entry_function=multi_input --function_input="2xi32=[1 2]" --function_input="2xi32=[3 4]" | FileCheck %s
 // RUN: iree-run-mlir --iree-hal-target-backends=vmvx --function-input='2xi32=[1 2]' --function-input='2xi32=[3 4]' %s | FileCheck %s
-// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=local-task --entry_function=multi_input --function_input="2xi32=[1 2]" --function_input="2xi32=[3 4]" | FileCheck --check-prefix=BENCHMARK %s
+// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=local-task --entry_function=multi_input --function_input="2xi32=[1 2]" --function_input="2xi32=[3 4]" | FileCheck --check-prefix=BENCHMARK %s
 
 // BENCHMARK-LABEL: BM_multi_input
 // CHECK-LABEL: EXEC @multi_input
diff --git a/tools/test/multiple_exported_functions.mlir b/tools/test/multiple_exported_functions.mlir
index a57f529..6ce0b1f 100644
--- a/tools/test/multiple_exported_functions.mlir
+++ b/tools/test/multiple_exported_functions.mlir
@@ -1,5 +1,5 @@
-// RUN: iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=local-task | FileCheck %s
-// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=vulkan | FileCheck %s)
+// RUN: iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=local-task | FileCheck %s
+// RUN: [[ $IREE_VULKAN_DISABLE == 1 ]] || (iree-compile --iree-input-type=mhlo --iree-hal-target-backends=vulkan-spirv --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=vulkan | FileCheck %s)
 
 module {
   func.func @foo1() -> tensor<4xf32> {
diff --git a/tools/test/repeated_return.mlir b/tools/test/repeated_return.mlir
index 238339a..332beb6 100644
--- a/tools/test/repeated_return.mlir
+++ b/tools/test/repeated_return.mlir
@@ -1,5 +1,5 @@
 // RUN: (iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-run-module --entry_function=many_tensor) | FileCheck %s
-// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=local-task --entry_function=many_tensor | FileCheck --check-prefix=BENCHMARK %s
+// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=local-task --entry_function=many_tensor | FileCheck --check-prefix=BENCHMARK %s
 // RUN: iree-run-mlir --iree-hal-target-backends=vmvx %s | FileCheck %s
 
 // BENCHMARK-LABEL: BM_many_tensor
diff --git a/tools/test/scalars.mlir b/tools/test/scalars.mlir
index cf9e717..636e0e2 100644
--- a/tools/test/scalars.mlir
+++ b/tools/test/scalars.mlir
@@ -1,5 +1,5 @@
 // RUN: (iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-run-module --entry_function=scalar --function_input=42) | FileCheck %s
-// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --driver=local-task --entry_function=scalar --function_input=42 | FileCheck --check-prefix=BENCHMARK %s
+// RUN: iree-compile --iree-hal-target-backends=vmvx --iree-mlir-to-vm-bytecode-module %s | iree-benchmark-module --device=local-task --entry_function=scalar --function_input=42 | FileCheck --check-prefix=BENCHMARK %s
 // RUN: (iree-run-mlir --iree-hal-target-backends=vmvx --function-input=42 %s) | FileCheck %s
 
 // BENCHMARK-LABEL: BM_scalar
diff --git a/build_tools/cmake/iree_native_test.cmake b/build_tools/cmake/iree_native_test.cmake
index 31bf152..d5ee62a 100644
--- a/build_tools/cmake/iree_native_test.cmake
+++ b/build_tools/cmake/iree_native_test.cmake
@@ -14,7 +14,7 @@
 #
 # Parameters:
 # NAME: name of target
 # DRIVER: If specified, will pass --driver=DRIVER to the test binary and adds
 #     a driver label to the test.
 # TEST_INPUT_FILE_ARG: If specified, the input file will be added to DATA and
 #     its device path appended to ARGS. Note that the device path may be
@@ -24,7 +24,7 @@
 #     a separate device (e.g. Android), these files will be pushed to the
 #     device. TEST_INPUT_FILE_ARG is automatically added if specified.
 # ARGS: additional arguments passed to the test binary. TEST_INPUT_FILE_ARG and
-#     --driver=DRIVER are automatically added if specified.
+#     --device=DRIVER are automatically added if specified.
 # SRC: binary target to run as the test.
 # LABELS: Additional labels to apply to the test. The package path is added
 #     automatically.
@@ -69,7 +69,7 @@
 
   # If driver was specified, add the corresponding test arg and label.
   if(DEFINED _RULE_DRIVER)
-    list(APPEND _RULE_ARGS "--driver=${_RULE_DRIVER}")
+    list(APPEND _RULE_ARGS "--device=${_RULE_DRIVER}")
     list(APPEND _RULE_LABELS "driver=${_RULE_DRIVER}")
   endif()
 
@@ -14,7 +14,7 @@
 # Parameters:
 # NAME: name of target
-# DRIVER: If specified, will pass --driver=DRIVER to the test binary and adds
+# DRIVER: If specified, will pass --device=DRIVER to the test binary and adds
 #     a driver label to the test.
 # TEST_INPUT_FILE_ARG: If specified, the input file will be added to DATA and